==> k4de-0.3.0.tgz: k4de-0.3.0/src/3d/classes/lightobj.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** lightobj.h
*/
#ifndef __LIGHTOBJ_H__
#define __LIGHTOBJ_H__

#include "csgobj.h"

class lightobj : public csgobj
{
public:
	lightobj(base *p = 0,char *n = "Untitled");
	lightobj(base *p,char *n,Vector3&,Vector3&,Vector3&);
	lightobj(base *p,lightobj *lc);
	~lightobj();

	virtual void	dumpNames(int tab,int tabsize);

	virtual int	addToParent(base *parent);

	virtual double	volume(int anim = 0);
};

#endif

==> k4de-0.4.0.tgz: k4de-0.4.0/src/3d/classes/lightobj.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** lightobj.h
*/
#ifndef __LIGHTOBJ_H__
#define __LIGHTOBJ_H__

#include "csgobj.h"

class lightobj : public csgobj
{
protected:
	double		r,g,b;
	double		fade_distance;
	double		fade_power;
	bool		media_attenuation;
	bool		media_interaction;

public:
	lightobj(base *p = 0,char *n = "Untitled");
	lightobj(base *p,char *n,Vector3&,Vector3&,Vector3&);
	lightobj(base *p,lightobj *lc);
	~lightobj();

	virtual void		setColor(double r,double g,double b);
	virtual void		setColor(Vector3 c);
	virtual void		setFadeDistance(double d);
	virtual void		setFadePower(double p);
	virtual void		setMediaAttenuation(bool ma);
	virtual void		setMediaInteraction(bool mi);
	
	virtual void		color(double &r,double &g,double &b);
	virtual Vector3		color();
	virtual double		red();
	virtual double		green();
	virtual double		blue();
	virtual double		fadeDistance();
	virtual double		fadePower();
	virtual bool		mediaAttenuation();
	virtual bool		mediaInteraction();
	
	virtual void		dumpNames(int tab,int tabsize);

	virtual int		addToParent(base *parent);

	virtual double		volume(int anim = 0);
};

#endif
